import { useContext, useEffect, useState } from 'react';
import SUIContext from '@s-ui/react-context';
import { TCF_WINDOW_API, TCF_VERSION } from './config';
import hasUserConsents from './hasUserConsents';
/**
 * @param {array} requiredConsents for example [1, 3, 8]
 * @return {boolean}
 */

export default function useUserConsents(requiredConsents) {
  /**
   * Consents acceptance state is inited based on the cookies from the
   * context, so we know the state of consents from the beginning, even
   * in SSR.
   */
  var _useContext = useContext(SUIContext),
      cookies = _useContext.cookies;

  var _useState = useState(function () {
    return hasUserConsents({
      requiredConsents: requiredConsents,
      cookies: cookies
    });
  }),
      areConsentsAccepted = _useState[0],
      setAreConsentsAccepted = _useState[1];
  /**
   * From then on, we listen for TCF events so consents changes
   * can be catched right away, no matter when, and react to them
   * wherever the hook is used.
   */


  useEffect(function () {
    var tcfApi = window[TCF_WINDOW_API];

    if (tcfApi) {
      var consentsListener = function consentsListener(_ref) {
        var eventStatus = _ref.eventStatus,
            purpose = _ref.purpose;
        if (eventStatus !== 'useractioncomplete') return;
        setAreConsentsAccepted(requiredConsents.every(function (purposeId) {
          return Boolean(purpose.consents[purposeId]);
        }));
      };

      tcfApi('addEventListener', TCF_VERSION, consentsListener);
      return function () {
        tcfApi('removeEventListener', TCF_VERSION, consentsListener);
      };
    }
  }, [requiredConsents]);
  return areConsentsAccepted;
}